==================
Прочти меня
==================

О проекте
-----------------
 
ApiStat - модуль генерирует json ответ на основе запроса из БД.

Требуется
-----------------
DJANGO
DJANGO_REST_FRAMEWORK

Установка
-----------------

1. pip install django-apistat
2. в setting.py добавляем наш модуль а так же необходимый rest_framework:

    INSTALLED_APPS = [
      ...

      'rest_framework',

      'apistat'

      ...

    ]

3. Добавляем в urls.py (путь 'stat/' может быть любой, на Ваше усмотрение)

    from django.urls import path, include

    urlpatterns = [
      ...


      path('stat/', include('apistat.urls', namespace='apistat')),

      ...

    ]

4. Заходим в админку и в таблицу Api stat sprs добавляем необходимые запросы 

5. Пример с http://127.0.0.1/

   http://127.0.0.1:8000/spr/list/ - получаем список отчетов

   http://127.0.0.1:8000/spr/report/1 - получаем данные отчета с идентификатором 1

Планы
-----------------

- запросы с параметрами (через POST в body или через параметры адресной строки)
- постраничное получение данных
- параметр в settings для соединения с бд, сейчас используется default

